Page 27 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 27

Home

    a house near the Temple of Solomon resulting in the
    name Knights Templar. The Templars were bound by a
    vow of poverty and were to live solely on alms. But
    donations became so enormous that they eventually
    abandoned their vow of poverty and spread themselves
    over Europe. By the end of the twelfth century they had
    become a rich and powerful body.

    By the end of the thirteenth century the rumors of
    their unscrupulous deeds and low moral life caused them

    eo

    to become suspect in the eyes of the clergy and the
    general public, word of their apostasy even reaching the
    Pope.

    On October 13, 1307, the King of France had all of
    the Templars in France arrested. Many confessed that
    they had been ordered to spit on the crucifix and had
    been urged to commit obscenities and practice unnatural
    vice. Later, and without duress of any kind, these

    confessions were repeated before the Pope by seventy-
    two of the French Knights.

    m

    Similar to other secret societies, the Templars had a
    double doctrine. The one presented to the majority of
    members at the lower level, and to the public, was
    replete with noble endeavors. If a member was able to

    ascend to a higher level by proving to his unscrupulous
    superiors that he could be trusted to keep their secrets
    and carry out their orders, he was told more about the
    true purpose of the order. These evil designs were most
    often communicated orally. The outward profession

    22

    The Secret Side of History